==> summerd-sdk-1.4.6.tgz: package/config/karma.conf.js <==
const webpackConfig = require('../config/webpack.test.config')
console.log(webpackConfig)

// Karma configuration
// Generated on Sat May 19 2018 06:35:44 GMT+0800 (CST)

// const base = `${process.cwd()}/test/index.js`

module.exports = function(config) {
  const conf = {

    // base path that will be used to resolve all patterns (eg. files, exclude)
    // basePath: '',

    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],
    // frameworks: ['mocha', 'sinon-chai'],

    reporters: ['spec', 'coverage'],

    // list of files / patterns to load in the browser
    files: [
      `${process.cwd()}/test/**/*.spec.js`,
      // base,
    ],

    // list of files to exclude
    exclude: [
    ],

    webpack: webpackConfig,

    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      '**/*.spec.js': ['webpack', 'sourcemap'],
    },

    // web server port
    // port: 9876,

    // enable / disable colors in the output (reporters and logs)
    // colors: true,

    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    // logLevel: config.LOG_INFO,

    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['Chrome'],

    coverageReporter: {
      dir: './coverage',
      reporters: [
        { type: 'lcov', subdir: '.' },
        { type: 'text-summary' }
      ]
    }
  }

  // conf.preprocessors[base] = ['webpack', 'sourcemap']

  config.set(conf)
}

==> summerd-sdk-1.4.7.tgz: package/config/karma.conf.js <==
const appConfig = require('../utils/get-app-config')
const webpackConfig = require('../config/webpack.test.config')

// Karma configuration
// Generated on Sat May 19 2018 06:35:44 GMT+0800 (CST)

const base = `${process.cwd()}/test/index.js`

module.exports = function(config) {
  const conf = {

    // base path that will be used to resolve all patterns (eg. files, exclude)
    // basePath: '',
    basePath: `${process.cwd()}/test`,

    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],
    // frameworks: ['mocha', 'sinon-chai'],

    reporters: ['spec', 'coverage'],

    // list of files / patterns to load in the browser
    files: [
      '**/*.spec.js'
    ],

    // list of files to exclude
    exclude: [
    ],

    webpack: webpackConfig,

    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      '**/*.spec.js': ['webpack', 'sourcemap'],
    },

    // web server port
    port: 9876,

    // enable / disable colors in the output (reporters and logs)
    colors: true,

    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,

    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['Chrome'],

    coverageReporter: {
      dir: './coverage',
      reporters: [
        { type: 'lcov', subdir: '.' },
        { type: 'text-summary' }
      ]
    },

    singleRun: true,
  }

  conf.preprocessors[base] = ['webpack', 'sourcemap']

  config.set(conf)
}
